@@ -14,6 +14,8 @@ from afqinsight.datasets import (
     AFQDataset,
     standardize_subject_id,
 )
+from sklearn.impute import SimpleImputer
+from sklearn.linear_model import Lasso
 
 data_path = op.join(afqi.__path__[0], "data")
 test_data_path = op.join(data_path, "test_data")
@@ -163,6 +165,69 @@ def test_AFQDataset_shape_len_index():
     assert repr(dataset) == "AFQDataset(n_samples=10, n_features=4)"  # nosec
 
 
+def test_AFQDataset_fit_transform():
+    sarica_dir = download_sarica()
+    dataset = AFQDataset.from_files(
+        fn_nodes=op.join(sarica_dir, "nodes.csv"),
+        fn_subjects=op.join(sarica_dir, "subjects.csv"),
+        dwi_metrics=["md", "fa"],
+        target_cols=["class"],
+        label_encode_cols=["class"],
+    )
+
+    # Test that model_fit fits the imputer
+    imputer = dataset.model_fit(SimpleImputer())
+    assert np.allclose(imputer.statistics_, np.nanmean(dataset.X, axis=0))
+
+    # Test that model_transform imputes the data
+    dataset_imputed = dataset.model_transform(imputer)
+    assert np.allclose(dataset_imputed.X, imputer.transform(dataset.X))
+
+    # Test that fit_transform does the same as fit and then transform
+    dataset_transformed = dataset.model_fit_transform(SimpleImputer())
+    assert np.allclose(dataset_transformed.X, dataset_imputed.X)
+
+
+def test_AFQDataset_copy():
+    wh_dir = download_weston_havens()
+    dataset_1 = AFQDataset.from_files(
+        fn_nodes=op.join(wh_dir, "nodes.csv"),
+        fn_subjects=op.join(wh_dir, "subjects.csv"),
+        dwi_metrics=["md", "fa"],
+        target_cols=["Age"],
+    )
+    dataset_2 = dataset_1.copy()
+
+    # Test that it copied
+    assert np.allclose(dataset_1.X, dataset_2.X, equal_nan=True)
+    assert dataset_1.groups == dataset_2.groups
+    assert dataset_1.group_names == dataset_2.group_names
+    assert dataset_1.subjects == dataset_2.subjects
+
+    # Test that it's a deep copy
+    dataset_1.X = np.zeros_like(dataset_2.X)
+    dataset_1.y = np.zeros_like(dataset_2.y)
+    assert not np.allclose(dataset_2.X, dataset_1.X, equal_nan=True)
+    assert not np.allclose(dataset_1.y, dataset_2.y, equal_nan=True)
+
+
+def test_AFQDataset_predict_score():
+    wh_dir = download_weston_havens()
+    dataset = AFQDataset.from_files(
+        fn_nodes=op.join(wh_dir, "nodes.csv"),
+        fn_subjects=op.join(wh_dir, "subjects.csv"),
+        dwi_metrics=["md", "fa"],
+        target_cols=["Age"],
+    )
+    dataset = dataset.model_fit_transform(SimpleImputer(strategy="median"))
+    estimator = dataset.model_fit(Lasso())
+    y_pred = dataset.model_predict(estimator)
+    assert np.allclose(estimator.predict(dataset.X), y_pred)
+    assert np.allclose(
+        estimator.score(dataset.X, dataset.y), dataset.model_score(estimator)
+    )
+
+
 def test_drop_target_na():
     dataset = AFQDataset(X=np.random.rand(10, 4), y=np.random.rand(10))
     dataset.y[:5] = np.nan
